// vincia11.cc is a part of the VINCIA plugin to PYTHIA 8
// This is a simple test program to run Z decays at LEP I and produce a HepMC file
// Uses same settings file as vincia01.cc
// Uses VINCIA for showering and matching and PYTHIA 8 for all else
// Copyright (c) 2015 Peter Skands

// PYTHIA and VINCIA include files
// (automatically defines and uses the Pythia and Vincia namespaces)
#include "Vincia.h"
#include "Pythia8Plugins/HepMC2.h"

// Main Program
int main(int argc, char* argv[]) {
  
  // Check if HepMC file name is provided.
  if (argc <= 1) {
    cout << endl;
    cout << "Use the program like this: ./vincia11 HepMCfilename" << endl;
    cout << "Please specify HepMCfilename (e.g. vincia11.hepmc)." << endl;
    cout << endl;
    cout << "For passing events directly to Rivet with a fifo pipe do: " << endl;
    cout << "   mkfifo myfifo" << endl;
    cout << "   ./vincia11 myfifo &" << endl;
    cout << "   rivet --analysis=ANALYSIS_NAME myfifo" << endl;
    cout << endl;
    return 0;
  }
  
  // Generator.
  Pythia pythia;
  VinciaPlugin vincia(&pythia,"vincia01.cmnd");
  
  // Extract number of Events.
  Settings& settings = pythia.settings;
  int nEvent = settings.mode("Main:numberOfEvents");

  // HepMC Interface.
  HepMC::Pythia8ToHepMC ToHepMC;
  HepMC::IO_GenEvent ascii_io(argv[1], std::ios::out);
  
  // Initialize.
  pythia.init();
  
  // Begin event loop.
  for (int iEvent = 0; iEvent < nEvent; ++iEvent) {
    
    if (!pythia.next()) continue;

    // HepMC.
    HepMC::GenEvent* hepmcevt = new HepMC::GenEvent();
    ToHepMC.fill_next_event( pythia, hepmcevt );
    ascii_io << hepmcevt;
    delete hepmcevt;
    
  }
  
  // Done.
  cout << endl << "Produced HepMC file named " << argv[1] << endl;
  return 0;
}
