// VinciaResolution.h is a part of the VINCIA plug-in to the PYTHIA 8 generator.
// Copyright (C) 2015 P. Skands.
// VINCIA is licenced under the GNU GPL version 2.
// Please respect the MCnet Guidelines for Event Generator Authors and Users, 
//               http://www.montecarlonet.org/GUIDELINES

// This file contains header information for VINCIA's Resolution class.
  
#ifndef VINCIARESOLUTION_H
#define VINCIARESOLUTION_H

#include "Pythia8/Basics.h"                   // Vec4
#include "Pythia8/Event.h"                    // Particle
#include "VinciaCommon.h"             // m2, printOut, etc.

using namespace Pythia8;

namespace Vincia {

  class Resolution {
    
  public:
    
    // Constructor.
    Resolution() : isInitPtr(false), isInit(false) {};

    // Destructor.
    virtual ~Resolution() {};

    // Initialize Pointers (must be done before init)
    void initPtr(Settings* settingsPtrIn) {
      settingsPtr    = settingsPtrIn; 
      isInitPtr=true;
    }
    
    // Initialize
    bool init();

    // Ordering variable (dimensionless)
    double yE(double,double,int typeIn=0);  //yE(y12,y23,EvolutionType)
    double yE(double*,double*,double*, int typeIn=0);//yE(p1,p2,p3,EvolutionType)
    double yE(Vec4,Vec4,Vec4, int typeIn=0);//yE(p1,p2,p3,EvolutionType)
    
    // Ordering variable (dimensionful)
    double Q2E(double, double, double, int typeIn=0); 
    double Q2E(Vec4, Vec4, Vec4, int typeIn=0); 
    double Q2E(Particle, Particle, Particle, int typeIn=0); 
 
    // Set verbose level
    void setVerbose(int verboseIn) {verbose = verboseIn;}

  private:

    // Is initialized?
    bool isInitPtr, isInit;

    // Pointer to PYTHIA 8 Settings database
    Settings* settingsPtr;

    // Evolution Variable normalization factors
    double pTnormalization, mDnormalization;

    // Verbose level
    int verbose;

  };

}

#endif
